@@ -102,11 +102,12 @@ namespace Nes
 		Ppu::Ppu(Cpu& c)
 		:
 		cpu    (c),
-		output (screen.pixels),
+		output (NULL),
 		model  (PPU_RP2C02),
 		rgbMap (NULL),
 		yuvMap (NULL)
 		{
+			output = Output(screen.pixels);
 			cycles.one = PPU_RP2C02_CC;
 			PowerOff();
 		}
@@ -312,17 +313,17 @@ namespace Nes
 			{
 				const byte data[11] =
 				{
-					regs.ctrl[0],
-					regs.ctrl[1],
-					regs.status,
-					scroll.address & 0xFF,
-					scroll.address >> 8,
-					scroll.latch & 0xFF,
-					scroll.latch >> 8,
-					scroll.xFine | scroll.toggle << 3,
-					regs.oam,
-					io.buffer,
-					io.latch
+					static_cast<byte>(regs.ctrl[0]),
+					static_cast<byte>(regs.ctrl[1]),
+					static_cast<byte>(regs.status),
+					static_cast<byte>(scroll.address & 0xFF),
+					static_cast<byte>(scroll.address >> 8),
+					static_cast<byte>(scroll.latch & 0xFF),
+					static_cast<byte>(scroll.latch >> 8),
+					static_cast<byte>(scroll.xFine | scroll.toggle << 3),
+					static_cast<byte>(regs.oam),
+					static_cast<byte>(io.buffer),
+					static_cast<byte>(io.latch)
 				};
 
 				state.Begin( AsciiId<'R','E','G'>::V ).Write( data ).End();
@@ -498,6 +499,7 @@ namespace Nes
 				case PPU_RP2C02:
 
 					regs.frame ^= Regs::FRAME_ODD;
+					// fallthrough
 
 				default:
 
@@ -1029,7 +1031,7 @@ namespace Nes
 
 			if ((address & 0x3F00) == 0x3F00) // Palette
 			{
-				io.latch = (io.latch & 0xC0) | palette.ram[address & 0x1F] & Coloring();
+				io.latch = (io.latch & 0xC0) | (palette.ram[address & 0x1F] & Coloring());
 				mask = 0x3F;
 			}
 			else // Non-Palette
@@ -1163,7 +1165,7 @@ namespace Nes
 			else switch (address & Y_TILE)
 			{
 				default:         address = (address & (Y_FINE ^ 0x7FFFU)) + (1U << 5); break;
-				case (29U << 5): address ^= NAME_HIGH;
+				case (29U << 5): address ^= NAME_HIGH; // fallthrough
 				case (31U << 5): address &= (Y_FINE|Y_TILE) ^ 0x7FFFU; break;
 			}
 		}
@@ -1829,6 +1831,7 @@ namespace Nes
 
 						if (cycles.count <= 338)
 							break;
+						// fallthrough
 
 					case 338:
 
@@ -1851,6 +1854,7 @@ namespace Nes
 							if (cycles.count <= HCLOCK_VBLANK_0)
 								break;
 						}
+						// fallthrough
 
 					case HCLOCK_VBLANK_0:
 						goto VBlank0;
@@ -1906,6 +1910,7 @@ namespace Nes
 
 						if (cycles.count <= cycles.hClock)
 							break;
+						// fallthrough
 
 					case 1:
 					case 9:
@@ -1946,6 +1951,7 @@ namespace Nes
 
 						if (cycles.count <= cycles.hClock)
 							break;
+						// fallthrough
 
 					case 2:
 					case 10:
@@ -1986,6 +1992,7 @@ namespace Nes
 
 						if (cycles.count <= cycles.hClock)
 							break;
+						// fallthrough
 
 					case 3:
 					case 11:
@@ -2031,6 +2038,7 @@ namespace Nes
 
 						if (cycles.count <= cycles.hClock)
 							break;
+						// fallthrough
 
 					case 4:
 					case 12:
@@ -2071,6 +2079,7 @@ namespace Nes
 
 						if (cycles.count <= cycles.hClock)
 							break;
+						// fallthrough
 
 					case 5:
 					case 13:
@@ -2111,6 +2120,7 @@ namespace Nes
 
 						if (cycles.count <= cycles.hClock)
 							break;
+						// fallthrough
 
 					case 6:
 					case 14:
@@ -2154,6 +2164,7 @@ namespace Nes
 
 						if (cycles.hClock == 255)
 							goto HActive255;
+						// fallthrough
 
 					case 7:
 					case 15:
@@ -2198,6 +2209,7 @@ namespace Nes
 
 						if (cycles.hClock != 64)
 							goto HActive;
+						// fallthrough
 
 					case 64:
 
@@ -2216,6 +2228,7 @@ namespace Nes
 
 						if (cycles.count <= 256)
 							break;
+						// fallthrough
 
 					case 256:
 
@@ -2225,6 +2238,7 @@ namespace Nes
 
 						if (cycles.count <= 257)
 							break;
+						// fallthrough
 
 					case 257:
 
@@ -2237,6 +2251,7 @@ namespace Nes
 
 						if (cycles.count <= 258)
 							break;
+						// fallthrough
 
 					case 258:
 					case 266:
@@ -2253,6 +2268,7 @@ namespace Nes
 
 						if (cycles.count <= cycles.hClock)
 							break;
+						// fallthrough
 
 					case 260:
 					case 268:
@@ -2272,6 +2288,7 @@ namespace Nes
 						if (cycles.count <= ++cycles.hClock)
 							break;
 					}
+					// fallthrough
 
 					case 261:
 					case 269:
@@ -2287,6 +2304,7 @@ namespace Nes
 
 						if (cycles.count <= ++cycles.hClock)
 							break;
+						// fallthrough
 
 					case 262:
 					case 270:
@@ -2301,6 +2319,7 @@ namespace Nes
 
 						if (cycles.count <= ++cycles.hClock)
 							break;
+						// fallthrough
 
 					case 263:
 					case 271:
@@ -2322,6 +2341,7 @@ namespace Nes
 						if (cycles.hClock == 320)
 							goto HBlankBg;
 					}
+					// fallthrough
 
 					case 264:
 					case 272:
@@ -2338,6 +2358,7 @@ namespace Nes
 							break;
 
 						goto HBlankSp;
+						// fallthrough
 
 					case 320:
 					HBlankBg:
@@ -2359,6 +2380,7 @@ namespace Nes
 
 						if (cycles.count <= 321)
 							break;
+						// fallthrough
 
 					case 321:
 
@@ -2367,6 +2389,7 @@ namespace Nes
 
 						if (cycles.count <= 322)
 							break;
+						// fallthrough
 
 					case 322:
 
@@ -2375,6 +2398,7 @@ namespace Nes
 
 						if (cycles.count <= 323)
 							break;
+						// fallthrough
 
 					case 323:
 
@@ -2384,6 +2408,7 @@ namespace Nes
 
 						if (cycles.count <= 324)
 							break;
+						// fallthrough
 
 					case 324:
 
@@ -2392,6 +2417,7 @@ namespace Nes
 
 						if (cycles.count <= 325)
 							break;
+						// fallthrough
 
 					case 325:
 
@@ -2400,6 +2426,7 @@ namespace Nes
 
 						if (cycles.count <= 326)
 							break;
+						// fallthrough
 
 					case 326:
 
@@ -2408,6 +2435,7 @@ namespace Nes
 
 						if (cycles.count <= 327)
 							break;
+						// fallthrough
 
 					case 327:
 
@@ -2416,6 +2444,7 @@ namespace Nes
 
 						if (cycles.count <= 328)
 							break;
+						// fallthrough
 
 					case 328:
 
@@ -2425,6 +2454,7 @@ namespace Nes
 
 						if (cycles.count <= 329)
 							break;
+						// fallthrough
 
 					case 329:
 
@@ -2433,6 +2463,7 @@ namespace Nes
 
 						if (cycles.count <= 330)
 							break;
+						// fallthrough
 
 					case 330:
 
@@ -2441,6 +2472,7 @@ namespace Nes
 
 						if (cycles.count <= 331)
 							break;
+						// fallthrough
 
 					case 331:
 
@@ -2450,6 +2482,7 @@ namespace Nes
 
 						if (cycles.count <= 332)
 							break;
+						// fallthrough
 
 					case 332:
 
@@ -2458,6 +2491,7 @@ namespace Nes
 
 						if (cycles.count <= 333)
 							break;
+						// fallthrough
 
 					case 333:
 
@@ -2466,6 +2500,7 @@ namespace Nes
 
 						if (cycles.count <= 334)
 							break;
+						// fallthrough
 
 					case 334:
 
@@ -2474,6 +2509,7 @@ namespace Nes
 
 						if (cycles.count <= 335)
 							break;
+						// fallthrough
 
 					case 335:
 
@@ -2482,6 +2518,7 @@ namespace Nes
 
 						if (cycles.count <= 336)
 							break;
+						// fallthrough
 
 					case 336:
 
@@ -2490,6 +2527,7 @@ namespace Nes
 
 						if (cycles.count <= 337)
 							break;
+						// fallthrough
 
 					case 337:
 
@@ -2513,6 +2551,7 @@ namespace Nes
 
 						if (cycles.count <= 338)
 							break;
+						// fallthrough
 
 					case 338:
 
@@ -2556,6 +2595,7 @@ namespace Nes
 									break;
 							}
 						}
+						// fallthrough
 
 					case HCLOCK_VBLANK_0:
 					VBlank0:
@@ -2565,6 +2605,7 @@ namespace Nes
 
 						if (cycles.count <= HCLOCK_VBLANK_1)
 							break;
+						// fallthrough
 
 					case HCLOCK_VBLANK_1:
 					VBlank1:
@@ -2575,6 +2616,7 @@ namespace Nes
 
 						if (cycles.count <= HCLOCK_VBLANK_2)
 							break;
+						// fallthrough
 
 					case HCLOCK_VBLANK_2:
 					VBlank2:
@@ -2597,6 +2639,7 @@ namespace Nes
 
 						regs.status = 0;
 						scanline = SCANLINE_HDUMMY;
+						// fallthrough
 
 					case HCLOCK_DUMMY+8:
 					case HCLOCK_DUMMY+16:
@@ -2636,6 +2679,7 @@ namespace Nes
 
 						if (cycles.count <= cycles.hClock)
 							break;
+						// fallthrough
 
 					case HCLOCK_DUMMY+2:
 					case HCLOCK_DUMMY+10:
@@ -2675,6 +2719,7 @@ namespace Nes
 
 						if (cycles.count <= cycles.hClock)
 							break;
+						// fallthrough
 
 					case HCLOCK_DUMMY+4:
 					case HCLOCK_DUMMY+12:
@@ -2714,6 +2759,7 @@ namespace Nes
 
 						if (cycles.count <= cycles.hClock)
 							break;
+						// fallthrough
 
 					case HCLOCK_DUMMY+6:
 					case HCLOCK_DUMMY+14:
@@ -2756,6 +2802,7 @@ namespace Nes
 
 						if (cycles.hClock != HCLOCK_DUMMY+256)
 							goto HDummyBg;
+						// fallthrough
 
 					case HCLOCK_DUMMY+256:
 					case HCLOCK_DUMMY+264:
@@ -2771,6 +2818,7 @@ namespace Nes
 
 						if (cycles.count <= cycles.hClock)
 							break;
+						// fallthrough
 
 					case HCLOCK_DUMMY+258:
 					case HCLOCK_DUMMY+266:
@@ -2786,6 +2834,7 @@ namespace Nes
 
 						if (cycles.count <= cycles.hClock)
 							break;
+						// fallthrough
 
 					case HCLOCK_DUMMY+260:
 					case HCLOCK_DUMMY+268:
@@ -2801,6 +2850,7 @@ namespace Nes
 
 						if (cycles.count <= cycles.hClock)
 							break;
+						// fallthrough
 
 					case HCLOCK_DUMMY+262:
 					case HCLOCK_DUMMY+270:
@@ -2834,6 +2884,7 @@ namespace Nes
 
 							goto HBlankBg;
 						}
+						// fallthrough
 
 					case HCLOCK_DUMMY+304:
 
@@ -3131,6 +3182,7 @@ namespace Nes
 						if (cycles.count <= 256)
 							break;
 					}
+					// fallthrough
 
 					case 256:
 
@@ -3138,6 +3190,7 @@ namespace Nes
 
 						if (cycles.count <= 257)
 							break;
+						// fallthrough
 
 					case 257:
 
@@ -3149,6 +3202,7 @@ namespace Nes
 
 						if (cycles.count <= 258)
 							break;
+						// fallthrough
 
 					case 258:
 					case 260:
@@ -3203,6 +3257,7 @@ namespace Nes
 							cycles.hClock = cycles.count + ((cycles.count & 0x7) == 3 || (cycles.count & 0x7) == 1);
 							break;
 						}
+						// fallthrough
 
 					case 320:
 					HBlankOff:
@@ -3219,6 +3274,7 @@ namespace Nes
 
 						if (cycles.count <= 321)
 							break;
+						// fallthrough
 
 					case 321:
 					case 322:
@@ -3242,6 +3298,7 @@ namespace Nes
 
 						if (cycles.count <= 338)
 							break;
+						// fallthrough
 
 					case 338:
 
@@ -3287,6 +3344,7 @@ namespace Nes
 									break;
 							}
 						}
+						// fallthrough
 
 					case HCLOCK_VBLANK_0:
 						goto VBlank0;
@@ -3319,6 +3377,7 @@ namespace Nes
 
 						regs.status = 0;
 						scanline = SCANLINE_HDUMMY;
+						// fallthrough
 
 					case HCLOCK_DUMMY+2:
 					case HCLOCK_DUMMY+4:
@@ -3486,6 +3545,7 @@ namespace Nes
 						if (cycles.count <= HCLOCK_DUMMY+318)
 							break;
 					}
+					// fallthrough
 
 					case HCLOCK_DUMMY+318:
 
