@@ -219,6 +219,7 @@ namespace Nes
 						CUSTOM_B4                  = MakeId<    4,  128,  128,  0,  0, CRM_0,  NMT_V,  0 >::ID,
 						CUSTOM_BTR                 = MakeId<   69,  512,  256,  8,  0, CRM_0,  NMT_V,  0 >::ID,
 						CUSTOM_EVENT               = MakeId<  105,  256,    0,  8,  0, CRM_8,  NMT_H,  0 >::ID,
+						CUSTOM_EVENT2              = MakeId<  555,  512,  256, 16,  0, CRM_8,  NMT_H,  0 >::ID,
 						CUSTOM_FFE3                = MakeId<    8,  256,  256,  8,  0, CRM_0,  NMT_X,  0 >::ID,
 						CUSTOM_FFE4                = MakeId<    6,  256,  256,  8,  0, CRM_32, NMT_X,  0 >::ID,
 						CUSTOM_FFE8                = MakeId<   17,  256,  256,  8,  0, CRM_0,  NMT_X,  0 >::ID,
@@ -271,6 +272,7 @@ namespace Nes
 						BMC_31IN1                  = MakeId<  229,  512,  256,  0,  0, CRM_0,  NMT_V,  0 >::ID,
 						BMC_35IN1                  = MakeId<  203,  128,   64,  0,  0, CRM_0,  NMT_V,  0 >::ID,
 						BMC_36IN1                  = MakeId<  200,  128,   64,  0,  0, CRM_0,  NMT_V,  0 >::ID,
+						BMC_60311C                 = MakeId<  289, 4096, 2048,  0,  0, CRM_32, NMT_X,  0 >::ID,
 						BMC_64IN1                  = MakeId<  204,  128,   64,  0,  0, CRM_0,  NMT_V,  0 >::ID,
 						BMC_72IN1                  = MakeId<  225, 1024,  512,  0,  0, CRM_0,  NMT_V,  0 >::ID,
 						BMC_76IN1                  = MakeId<  226, 2048,    0,  0,  0, CRM_8,  NMT_H,  0 >::ID,
@@ -566,8 +568,8 @@ namespace Nes
 						UNL_UXROM_M5               = MakeId<  180, 4096,    8,  8,  0, CRM_0,  NMT_X,  0 >::ID,
 						UNL_TRXROM                 = MakeId<    4,  512,  256,  8,  0, CRM_0,  NMT_4,  0 >::ID,
 						UNL_XZY                    = MakeId<  176, 1024,  256,  8,  0, CRM_0,  NMT_X,  0 >::ID,
-						UNL_MMC3BIGCHRRAM          = MakeId<    4,  512,    0,  0,  0, CRM_32, NMT_X,  0 >::ID,
-						UNL_MMC3BIGPRGROM          = MakeId<    4, 1024,    0,  8,  0, CRM_8,  NMT_X,  0 >::ID,
+						UNL_MMC3BIGCHRRAM          = MakeId<    4,  512,    0,  8,  0, CRM_32, NMT_X,  0 >::ID,
+						UNL_MMC3BIGPRGROM          = MakeId<    4, 1024,    0,  8,  0, CRM_32, NMT_X,  0 >::ID,
 						// Waixing
 						WAIXING_PS2_0              = MakeId<   15, 1024,    0,  0,  0, CRM_8,  NMT_V,  0 >::ID,
 						WAIXING_PS2_1              = MakeId<   15, 1024,    0,  8,  0, CRM_8,  NMT_V,  0 >::ID,
